import React, { forwardRef } from 'react';
import cn from 'classnames';
import CheckedIcon from '@alfalab/icons-classic/TickXsWhiteIcon';
import IndeterminateIcon from '@alfalab/icons-classic/CheckIndeterminateSWhiteIcon';

var styles = {"component":"checkbox__component_16v64","box":"checkbox__box_16v64","checked":"checkbox__checked_16v64","disabled":"checkbox__disabled_16v64","indeterminate":"checkbox__indeterminate_16v64","content":"checkbox__content_16v64","label":"checkbox__label_16v64","hint":"checkbox__hint_16v64","indeterminateIcon":"checkbox__indeterminateIcon_16v64"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, onChange, className, name, disabled, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, className, {
            [styles.disabled]: disabled,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
        }), ref: ref },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, null),
            indeterminate && !checked && (React.createElement(IndeterminateIcon, { className: styles.indeterminateIcon }))),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint)))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
